This quickstart will get you going with a Java and Play Framework application that uses a WebSocket, deployed to Heroku. For general information on how to develop and architect apps for use on Heroku, see [Architecting Applications for Heroku](https://devcenter.heroku.com/articles/architecting-apps).

>note
> Sample code for the [demo application](https://github.com/heroku/play-ws-test) is available on GitHub. Edits and enhancements are welcome. Just fork the repository, make your changes and send us a pull request.

## Prerequisites

* Java, Play Framework 2.x, Git, and the Heroku client (as described in the [basic Java quickstart](java))
* A Heroku user account.  [Signup is free and instant](https://api.heroku.com/signup/devcenter).

## Create a Play Framework Java app that uses a WebSocket

The sample application provides a simple example of using a WebSocket with Java and Play. You can clone the sample and follow along with the code as you read. If you'd rather write the app yourself you can add the sample code to a new Play app as you go.

### Option 1. Clone the sample app

If you want to get going more quickly you can just clone the sample app:

```term
$ git clone git@github.com:heroku/play-ws-test.git
Cloning into 'play-ws-test'...
remote: Counting objects: 31, done.
remote: Compressing objects: 100% (24/24), done.
remote: Total 31 (delta 0), reused 31 (delta 0)
Receiving objects: 100% (31/31), 38.33 KiB | 0 bytes/s, done.
Checking connectivity... done
```

### Option 2. Create a new Play app

```term

$ play new play22test
mywebsocketapp

Which template do you want to use for this new application? 

  1             - Create a simple Scala application
  2             - Create a simple Java application

2
OK, application mywebsocketapp is created.

Have fun!

```

Choose an application name and Java as the language.

## The sample application

The sample application renders a simple web page that will open a WebSocket to the backend. The server will send a payload containing the time over the WebSocket once a second. That time will be displayed on the page.

There are 3 important pieces to the interaction that takes place here: a controller method that returns a WebSocket object, a JavaScript method that opens that WebSocket, and an Akka actor that sends the payload across that WebSocket every second. Let's explore each.

### Returning a WebSocket from a controller method

You can [return a WebSocket](http://www.playframework.com/documentation/2.2.x/JavaWebSockets) from a Play controller method.

There is an example in `Application.java` in the sample application:

```java
In file `play22test/app/controllers/Application.java` add:
package controllers;

import static java.util.concurrent.TimeUnit.SECONDS;
import models.Pinger;
import play.libs.Akka;
import play.libs.F.Callback0;
import play.mvc.Controller;
import play.mvc.Result;
import play.mvc.WebSocket;
import scala.concurrent.duration.Duration;
import views.html.index;
import akka.actor.ActorRef;
import akka.actor.Cancellable;
import akka.actor.Props;

public class Application extends Controller {
    public static WebSocket<String> pingWs() {
        return new WebSocket<String>() {
            public void onReady(WebSocket.In<String> in, WebSocket.Out<String> out) {
                final ActorRef pingActor = Akka.system().actorOf(Props.create(Pinger.class, in, out));
                final Cancellable cancellable = Akka.system().scheduler().schedule(Duration.create(1, SECONDS),
                                                   Duration.create(1, SECONDS),
                                                   pingActor,
                                                   "Tick",
                                                   Akka.system().dispatcher(),
                                                   null
                                                   );

                in.onClose(new Callback0() {
                  @Override
                  public void invoke() throws Throwable {
                    cancellable.cancel();
                  }
                });
            }

        };
    }

    public static Result pingJs() {
        return ok(views.js.ping.render());
    }

    public static Result index() {
        return ok(index.render());
    }
}

package controllers;

import static java.util.concurrent.TimeUnit.SECONDS;
import models.Pinger;
import play.libs.Akka;
import play.libs.F.Callback0;
import play.mvc.Controller;
import play.mvc.Result;
import play.mvc.WebSocket;
import scala.concurrent.duration.Duration;
import views.html.index;
import akka.actor.ActorRef;
import akka.actor.Cancellable;
import akka.actor.Props;

public class Application extends Controller {
    public static WebSocket<String> pingWs() {
        return new WebSocket<String>() {
            public void onReady(WebSocket.In<String> in, WebSocket.Out<String> out) {
                final ActorRef pingActor = Akka.system().actorOf(Props.create(Pinger.class, in, out));
                final Cancellable cancellable = Akka.system().scheduler().schedule(Duration.create(1, SECONDS),
                                                   Duration.create(1, SECONDS),
                                                   pingActor,
                                                   "Tick",
                                                   Akka.system().dispatcher(),
                                                   null
                                                   );

                in.onClose(new Callback0() {
                  @Override
                  public void invoke() throws Throwable {
                    cancellable.cancel();
                  }
                });
            }

        };
    }

    public static Result pingJs() {
        return ok(views.js.ping.render());
    }

    public static Result index() {
        return ok(index.render());
    }
}
```

This method returns a new [WebSocket](http://www.playframework.com/documentation/2.0/api/java/play/mvc/WebSocket.html) object that has a String as its payload. In the WebSocket object we define the onReady method to talk to an actor via the Akka scheduler. The work of sending data over the socket will occur in that actor.

The other methods will render our `js` and `html` templates.


We'll also need a route to be set up for these methods in our `routes` file:

```
In file `play22test/conf/routes` add:
# Home page
GET     /                           controllers.Application.index()
GET     /pingWs                     controllers.Application.pingWs()
GET     /assets/javascripts/ping.js controllers.Application.pingJs()

# Map static resources from the /public folder to the /assets URL path
GET     /assets/*file               controllers.Assets.at(path="/public", file)

# Home page
GET     /                           controllers.Application.index()
GET     /pingWs                     controllers.Application.pingWs()
GET     /assets/javascripts/ping.js controllers.Application.pingJs()

# Map static resources from the /public folder to the /assets URL path
GET     /assets/*file               controllers.Assets.at(path="/public", file)
```

### Sending data over a WebSocket

In the controller example you'll notice that we pass around the `in` and `out` streams of the WebSocket. In our actor we're able to read from and write to these streams just like any other IO stream. Here's the code for the `Pinger` actor:

```java
In file `play22test/app/models/Pinger.java` add:
package models;

import play.*;
import play.mvc.*;
import play.libs.*;

import scala.concurrent.duration.Duration;
import java.util.concurrent.TimeUnit;
import akka.actor.UntypedActor;
import java.util.Calendar;
import java.text.SimpleDateFormat;

public class Pinger extends UntypedActor {
    WebSocket.In<String> in;
    WebSocket.Out<String> out;

    public Pinger(WebSocket.In<String> in, WebSocket.Out<String> out) {
        this.in = in;
        this.out = out;
    }

    @Override
    public void onReceive(Object message) {
        if (message.equals("Tick")) {
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            Calendar cal = Calendar.getInstance();
            out.write(sdf.format(cal.getTime()));
        } else {
            unhandled(message);
        }
    }
}

package models;

import play.*;
import play.mvc.*;
import play.libs.*;

import scala.concurrent.duration.Duration;
import java.util.concurrent.TimeUnit;
import akka.actor.UntypedActor;
import java.util.Calendar;
import java.text.SimpleDateFormat;

public class Pinger extends UntypedActor {
    WebSocket.In<String> in;
    WebSocket.Out<String> out;

    public Pinger(WebSocket.In<String> in, WebSocket.Out<String> out) {
        this.in = in;
        this.out = out;
    }

    @Override
    public void onReceive(Object message) {
        if (message.equals("Tick")) {
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            Calendar cal = Calendar.getInstance();
            out.write(sdf.format(cal.getTime()));
        } else {
            unhandled(message);
        }
    }
}
```

You'll notice that this actor counts on the schedule defined in the controller method to send it a "Tick" message every second. When that happens it sends the current date and time over the WebSocket.

### Connecting to a WebSocket

The final piece is the client code that will call the WebSocket. For this our sample application uses Scala js and HTML templates called `ping.scala.js` and `index.scala.js` respectively.

`index.scala.js` provides a `div` to display the data in and references the JavaScript:

```java
In file `play22test/app/views/index.scala.html` add:
@main("Welcome to Play") {

    <strong>Stats</strong><br>
    <div id="ping"></div>

   <script type="text/javascript" charset="utf-8" src="@routes.Application.pingJs()"></script>
}

@main("Welcome to Play") {

    <strong>Stats</strong><br>
    <div id="ping"></div>

   <script type="text/javascript" charset="utf-8" src="@routes.Application.pingJs()"></script>
}
```

`ping.scala.js` connects to our WebSocket and defines the `receiveEvent` method to populate the dates into the displayed `div` as they come across:

```javascript
In file `play22test/app/views/ping.scala.js` add:
$(function() {
    var WS = window['MozWebSocket'] ? MozWebSocket : WebSocket
    var dateSocket = new WS("@routes.Application.pingWs().webSocketURL(request)")

    var receiveEvent = function(event) {
        $("#ping").html("Last ping: "+event.data);
    }

    dateSocket.onmessage = receiveEvent
})

$(function() {
    var WS = window['MozWebSocket'] ? MozWebSocket : WebSocket
    var dateSocket = new WS("@routes.Application.pingWs().webSocketURL(request)")

    var receiveEvent = function(event) {
        $("#ping").html("Last ping: "+event.data);
    }

    dateSocket.onmessage = receiveEvent
})
```

## Deploy the application to Heroku

### Store your app in Git

If you haven't done so already put your application into a git repository:

```term
$ cd play22test && git init 
$ cd play22test && git add . 
$ cd play22test && git commit -m "Ready to deploy" 
```

### Create the app

```term
$ cd play22test && heroku create 
Creating shrouded-basin-4761... done, stack is cedar
http://shrouded-basin-4761.herokuapp.com/ | git@heroku.com:shrouded-basin-4761.git
Git remote heroku added
```

### Deploy your code

```term
$ cd play22test && git push heroku master 

-----> Play 2.x - Java app detected
-----> Installing OpenJDK 1.6...done
-----> Building app with sbt
-----> Running: sbt clean compile stage
       Getting org.scala-sbt sbt 0.13.0 ...
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/sbt/0.13.0/jars/sbt.jar ...
       	[SUCCESSFUL ] org.scala-sbt#sbt;0.13.0!sbt.jar (354ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/main/0.13.0/jars/main.jar ...
       	[SUCCESSFUL ] org.scala-sbt#main;0.13.0!main.jar (550ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/compiler-interface/0.13.0/jars/compiler-interface-bin.jar ...
       	[SUCCESSFUL ] org.scala-sbt#compiler-interface;0.13.0!compiler-interface-bin.jar (300ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/compiler-interface/0.13.0/jars/compiler-interface-src.jar ...
       	[SUCCESSFUL ] org.scala-sbt#compiler-interface;0.13.0!compiler-interface-src.jar (282ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/precompiled-2_8_2/0.13.0/jars/compiler-interface-bin.jar ...
       	[SUCCESSFUL ] org.scala-sbt#precompiled-2_8_2;0.13.0!compiler-interface-bin.jar (365ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/precompiled-2_9_2/0.13.0/jars/compiler-interface-bin.jar ...
       	[SUCCESSFUL ] org.scala-sbt#precompiled-2_9_2;0.13.0!compiler-interface-bin.jar (529ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/precompiled-2_9_3/0.13.0/jars/compiler-interface-bin.jar ...
       	[SUCCESSFUL ] org.scala-sbt#precompiled-2_9_3;0.13.0!compiler-interface-bin.jar (319ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/actions/0.13.0/jars/actions.jar ...
       	[SUCCESSFUL ] org.scala-sbt#actions;0.13.0!actions.jar (502ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/main-settings/0.13.0/jars/main-settings.jar ...
       	[SUCCESSFUL ] org.scala-sbt#main-settings;0.13.0!main-settings.jar (526ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/interface/0.13.0/jars/interface.jar ...
       	[SUCCESSFUL ] org.scala-sbt#interface;0.13.0!interface.jar (327ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/io/0.13.0/jars/io.jar ...
       	[SUCCESSFUL ] org.scala-sbt#io;0.13.0!io.jar (641ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/ivy/0.13.0/jars/ivy.jar ...
       	[SUCCESSFUL ] org.scala-sbt#ivy;0.13.0!ivy.jar (684ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/launcher-interface/0.13.0/jars/launcher-interface.jar ...
       	[SUCCESSFUL ] org.scala-sbt#launcher-interface;0.13.0!launcher-interface.jar (365ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/logging/0.13.0/jars/logging.jar ...
       	[SUCCESSFUL ] org.scala-sbt#logging;0.13.0!logging.jar (337ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/process/0.13.0/jars/process.jar ...
       	[SUCCESSFUL ] org.scala-sbt#process;0.13.0!process.jar (341ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/run/0.13.0/jars/run.jar ...
       	[SUCCESSFUL ] org.scala-sbt#run;0.13.0!run.jar (333ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/command/0.13.0/jars/command.jar ...
       	[SUCCESSFUL ] org.scala-sbt#command;0.13.0!command.jar (250ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/classpath/0.13.0/jars/classpath.jar ...
       	[SUCCESSFUL ] org.scala-sbt#classpath;0.13.0!classpath.jar (335ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/completion/0.13.0/jars/completion.jar ...
       	[SUCCESSFUL ] org.scala-sbt#completion;0.13.0!completion.jar (466ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/api/0.13.0/jars/api.jar ...
       	[SUCCESSFUL ] org.scala-sbt#api;0.13.0!api.jar (472ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/compiler-integration/0.13.0/jars/compiler-integration.jar ...
       	[SUCCESSFUL ] org.scala-sbt#compiler-integration;0.13.0!compiler-integration.jar (806ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/compiler-ivy-integration/0.13.0/jars/compiler-ivy-integration.jar ...
       	[SUCCESSFUL ] org.scala-sbt#compiler-ivy-integration;0.13.0!compiler-ivy-integration.jar (326ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/relation/0.13.0/jars/relation.jar ...
       	[SUCCESSFUL ] org.scala-sbt#relation;0.13.0!relation.jar (472ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/task-system/0.13.0/jars/task-system.jar ...
       	[SUCCESSFUL ] org.scala-sbt#task-system;0.13.0!task-system.jar (332ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/tasks/0.13.0/jars/tasks.jar ...
       	[SUCCESSFUL ] org.scala-sbt#tasks;0.13.0!tasks.jar (372ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/tracking/0.13.0/jars/tracking.jar ...
       	[SUCCESSFUL ] org.scala-sbt#tracking;0.13.0!tracking.jar (443ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/testing/0.13.0/jars/testing.jar ...
       	[SUCCESSFUL ] org.scala-sbt#testing;0.13.0!testing.jar (407ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/control/0.13.0/jars/control.jar ...
       	[SUCCESSFUL ] org.scala-sbt#control;0.13.0!control.jar (299ms)
       downloading http://s3pository.heroku.com/maven-central/org/scala-lang/scala-reflect/2.10.2/scala-reflect-2.10.2.jar ...
       	[SUCCESSFUL ] org.scala-lang#scala-reflect;2.10.2!scala-reflect.jar (442ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/collections/0.13.0/jars/collections.jar ...
       	[SUCCESSFUL ] org.scala-sbt#collections;0.13.0!collections.jar (550ms)
       downloading http://s3pository.heroku.com/maven-central/jline/jline/2.11/jline-2.11.jar ...
       	[SUCCESSFUL ] jline#jline;2.11!jline.jar (290ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/incremental-compiler/0.13.0/jars/incremental-compiler.jar ...
       	[SUCCESSFUL ] org.scala-sbt#incremental-compiler;0.13.0!incremental-compiler.jar (553ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/compile/0.13.0/jars/compile.jar ...
       	[SUCCESSFUL ] org.scala-sbt#compile;0.13.0!compile.jar (534ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/persist/0.13.0/jars/persist.jar ...
       	[SUCCESSFUL ] org.scala-sbt#persist;0.13.0!persist.jar (222ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/classfile/0.13.0/jars/classfile.jar ...
       	[SUCCESSFUL ] org.scala-sbt#classfile;0.13.0!classfile.jar (469ms)
       downloading http://typesafe.artifactoryonline.com/typesafe/ivy-releases/org.scala-tools.sbinary/sbinary_2.10/0.4.2/jars/sbinary_2.10.jar ...
       	[SUCCESSFUL ] org.scala-tools.sbinary#sbinary_2.10;0.4.2!sbinary_2.10.jar (160ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/cross/0.13.0/jars/cross.jar ...
       	[SUCCESSFUL ] org.scala-sbt#cross;0.13.0!cross.jar (263ms)
       downloading http://s3pository.heroku.com/maven-central/org/apache/ivy/ivy/2.3.0-rc1/ivy-2.3.0-rc1.jar ...
       	[SUCCESSFUL ] org.apache.ivy#ivy;2.3.0-rc1!ivy.jar (230ms)
       downloading http://s3pository.heroku.com/maven-central/com/jcraft/jsch/0.1.46/jsch-0.1.46.jar ...
       	[SUCCESSFUL ] com.jcraft#jsch;0.1.46!jsch.jar (256ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/cache/0.13.0/jars/cache.jar ...
       	[SUCCESSFUL ] org.scala-sbt#cache;0.13.0!cache.jar (272ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/test-agent/0.13.0/jars/test-agent.jar ...
       	[SUCCESSFUL ] org.scala-sbt#test-agent;0.13.0!test-agent.jar (291ms)
       downloading http://s3pository.heroku.com/maven-central/org/scala-sbt/test-interface/1.0/test-interface-1.0.jar ...
       	[SUCCESSFUL ] org.scala-sbt#test-interface;1.0!test-interface.jar (213ms)
       downloading http://s3pository.heroku.com/ivy-typesafe-releases/org.scala-sbt/apply-macro/0.13.0/jars/apply-macro.jar ...
       	[SUCCESSFUL ] org.scala-sbt#apply-macro;0.13.0!apply-macro.jar (346ms)
       :: retrieving :: org.scala-sbt#boot-app
       	confs: [default]
       	43 artifacts copied, 0 already retrieved (12440kB/172ms)
       Getting Scala 2.10.2 (for sbt)...
       downloading http://s3pository.heroku.com/maven-central/org/scala-lang/scala-compiler/2.10.2/scala-compiler-2.10.2.jar ...
       	[SUCCESSFUL ] org.scala-lang#scala-compiler;2.10.2!scala-compiler.jar (2199ms)
       downloading http://s3pository.heroku.com/maven-central/org/scala-lang/scala-library/2.10.2/scala-library-2.10.2.jar ...
       	[SUCCESSFUL ] org.scala-lang#scala-library;2.10.2!scala-library.jar (1259ms)
       downloading http://s3pository.heroku.com/maven-central/org/scala-lang/jline/2.10.2/jline-2.10.2.jar ...
       	[SUCCESSFUL ] org.scala-lang#jline;2.10.2!jline.jar (207ms)
       downloading http://s3pository.heroku.com/maven-central/org/fusesource/jansi/jansi/1.4/jansi-1.4.jar ...
       	[SUCCESSFUL ] org.fusesource.jansi#jansi;1.4!jansi.jar (197ms)
       :: retrieving :: org.scala-sbt#boot-scala
       	confs: [default]
       	5 artifacts copied, 0 already retrieved (24390kB/50ms)
       [warn] The global sbt directory is now versioned and is located at /tmp/build_3ae9a649-b02b-41f5-ac89-f0034c39a122/.sbt_home/.sbt/0.13.
       [warn]   You are seeing this warning because there is global configuration in /tmp/build_3ae9a649-b02b-41f5-ac89-f0034c39a122/.sbt_home/.sbt but not in /tmp/build_3ae9a649-b02b-41f5-ac89-f0034c39a122/.sbt_home/.sbt/0.13.
       [warn]   The global sbt directory may be changed via the sbt.global.base system property.
       [info] Loading project definition from /tmp/build_3ae9a649-b02b-41f5-ac89-f0034c39a122/project
       [warn] Multiple resolvers having different access mechanism configured with same name 'typesafe-ivy-releases'. To avoid conflict, Remove duplicate project resolvers (`resolvers`) or rename publishing resolver (`publishTo`).
       [info] Set current project to mywebsocketapp (in build file:/tmp/build_3ae9a649-b02b-41f5-ac89-f0034c39a122/)
       [success] Total time: 0 s, completed Oct 3, 2013 9:15:39 PM
       [info] Updating {file:/tmp/build_3ae9a649-b02b-41f5-ac89-f0034c39a122/}build_3ae9a649-b02b-41f5-ac89-f0034c39a122...
       [info] Resolving org.scala-lang#scala-library;2.10.2 ...
       [info] Resolving com.typesafe.play#play-java-jdbc_2.10;2.2.0 ...
       [info] Resolving com.typesafe.play#play-jdbc_2.10;2.2.0 ...
       [info] Resolving com.typesafe.play#play_2.10;2.2.0 ...
       [info] Resolving com.typesafe.play#sbt-link;2.2.0 ...
       [info] Resolving org.javassist#javassist;3.18.0-GA ...
       [info] Resolving com.typesafe.play#play-exceptions;2.2.0 ...
       [info] Resolving com.typesafe.play#templates_2.10;2.2.0 ...
       [info] Resolving com.github.scala-incubator.io#scala-io-file_2.10;0.4.2 ...
       [info] Resolving com.github.scala-incubator.io#scala-io-core_2.10;0.4.2 ...
       [info] Resolving com.jsuereth#scala-arm_2.10;1.3 ...
       [info] Resolving com.typesafe.play#play-iteratees_2.10;2.2.0 ...
       [info] Resolving org.scala-stm#scala-stm_2.10;0.7 ...
       [info] Resolving com.typesafe#config;1.0.2 ...
       [info] Resolving com.typesafe.play#play-json_2.10;2.2.0 ...
       [info] Resolving com.typesafe.play#play-functional_2.10;2.2.0 ...
       [info] Resolving com.typesafe.play#play-datacommons_2.10;2.2.0 ...
       [info] Resolving joda-time#joda-time;2.2 ...
       [info] Resolving org.joda#joda-convert;1.3.1 ...
       [info] Resolving com.fasterxml.jackson.core#jackson-annotations;2.2.2 ...
       [info] Resolving com.fasterxml#oss-parent;10 ...
       [info] Resolving com.fasterxml.jackson.core#jackson-core;2.2.2 ...
       [info] Resolving com.fasterxml#oss-parent;10 ...
       [info] Resolving com.fasterxml.jackson.core#jackson-databind;2.2.2 ...
       [info] Resolving com.fasterxml#oss-parent;10 ...
       [info] Resolving org.scala-lang#scala-reflect;2.10.2 ...
       [info] Resolving io.netty#netty;3.7.0.Final ...
       [info] Resolving org.sonatype.oss#oss-parent;7 ...
       [info] Resolving com.typesafe.netty#netty-http-pipelining;1.1.2 ...
       [info] Resolving org.slf4j#slf4j-api;1.7.5 ...
       [info] Resolving org.slf4j#slf4j-parent;1.7.5 ...
       [info] Resolving org.slf4j#jul-to-slf4j;1.7.5 ...
       [info] Resolving org.slf4j#slf4j-parent;1.7.5 ...
       [info] Resolving org.slf4j#jcl-over-slf4j;1.7.5 ...
       [info] Resolving org.slf4j#slf4j-parent;1.7.5 ...
       [info] Resolving ch.qos.logback#logback-core;1.0.13 ...
       [info] Resolving ch.qos.logback#logback-parent;1.0.13 ...
       [info] Resolving ch.qos.logback#logback-classic;1.0.13 ...
       [info] Resolving ch.qos.logback#logback-parent;1.0.13 ...
       [info] Resolving com.typesafe.akka#akka-actor_2.10;2.2.0 ...
       [info] Resolving com.typesafe.akka#akka-slf4j_2.10;2.2.0 ...
       [info] Resolving org.apache.commons#commons-lang3;3.1 ...
       [info] Resolving org.apache.commons#commons-parent;22 ...
       [info] Resolving org.apache#apache;9 ...
       [info] Resolving com.ning#async-http-client;1.7.18 ...
       [info] Resolving org.sonatype.oss#oss-parent;5 ...
       [info] Resolving oauth.signpost#signpost-core;1.2.1.2 ...
       [info] Resolving oauth.signpost#oauth-signpost;1.2.1.2 ...
       [info] Resolving commons-codec#commons-codec;1.3 ...
       [info] Resolving oauth.signpost#signpost-commonshttp4;1.2.1.2 ...
       [info] Resolving oauth.signpost#oauth-signpost;1.2.1.2 ...
       [info] Resolving org.apache.httpcomponents#httpcore;4.0.1 ...
       [info] Resolving org.apache.httpcomponents#httpcomponents-core;4.0.1 ...
       [info] Resolving org.apache.httpcomponents#project;4.0 ...
       [info] Resolving org.apache.httpcomponents#httpclient;4.0.1 ...
       [info] Resolving org.apache.httpcomponents#httpcomponents-client;4.0.1 ...
       [info] Resolving org.apache.httpcomponents#project;4.0 ...
       [info] Resolving commons-logging#commons-logging;1.1.1 ...
       [info] Resolving org.apache.commons#commons-parent;5 ...
       [info] Resolving org.apache#apache;4 ...
       [info] Resolving xerces#xercesImpl;2.11.0 ...
       [info] Resolving xml-apis#xml-apis;1.4.01 ...
       [info] Resolving javax.transaction#jta;1.1 ...
       [info] Resolving com.jolbox#bonecp;0.8.0-rc1 ...
       [info] Resolving com.jolbox#bonecp-parent;0.8.0-rc1 ...
       [info] Resolving com.google.guava#guava;14.0.1 ...
       [info] Resolving com.h2database#h2;1.3.172 ...
       [info] Resolving tyrex#tyrex;1.0.1 ...
       [info] Resolving com.typesafe.play#play-java_2.10;2.2.0 ...
       [info] Resolving org.yaml#snakeyaml;1.12 ...
       [info] Resolving org.hibernate#hibernate-validator;5.0.1.Final ...
       [info] Resolving org.hibernate#hibernate-validator-parent;5.0.1.Final ...
       [info] Resolving org.jboss.arquillian#arquillian-bom;1.0.2.Final ...
       [info] Resolving org.jboss.shrinkwrap#shrinkwrap-bom;1.0.1 ...
       [info] Resolving org.jboss.shrinkwrap.resolver#shrinkwrap-resolver-bom;1.0.0-beta-7 ...
       [info] Resolving org.jboss.shrinkwrap.descriptors#shrinkwrap-descriptors-bom;2.0.0-alpha-3 ...
       [info] Resolving javax.validation#validation-api;1.1.0.Final ...
       [info] Resolving org.jboss.logging#jboss-logging;3.1.1.GA ...
       [info] Resolving org.jboss#jboss-parent;7 ...
       [info] Resolving com.fasterxml#classmate;0.8.0 ...
       [info] Resolving org.sonatype.oss#oss-parent;7 ...
       [info] Resolving org.springframework#spring-context;3.2.3.RELEASE ...
       [info] Resolving org.springframework#spring-core;3.2.3.RELEASE ...
       [info] Resolving org.springframework#spring-beans;3.2.3.RELEASE ...
       [info] Resolving org.reflections#reflections;0.9.8 ...
       [info] Resolving org.reflections#reflections-parent;0.9.8 ...
       [info] Resolving dom4j#dom4j;1.6.1 ...
       [info] Resolving com.google.code.findbugs#jsr305;2.0.1 ...
       [info] Resolving javax.servlet#javax.servlet-api;3.0.1 ...
       [info] Resolving net.java#jvnet-parent;1 ...
       [info] Resolving com.typesafe.play#play-java-ebean_2.10;2.2.0 ...
       [info] Resolving org.avaje.ebeanorm#avaje-ebeanorm;3.2.2 ...
       [info] Resolving org.avaje#avaje-javaparent;1.2 ...
       [info] Resolving org.avaje#avaje-parent;1.2 ...
       [info] Resolving org.sonatype.oss#oss-parent;7 ...
       [info] Resolving org.avaje.ebeanorm#avaje-ebeanorm-agent;3.2.1 ...
       [info] Resolving org.hibernate.javax.persistence#hibernate-jpa-2.0-api;1.0.1.Final ...
       [info] Resolving com.typesafe.play#play-cache_2.10;2.2.0 ...
       [error] SERVER ERROR: Gateway Timeout url=http://s3pository.heroku.com/maven-central/com/typesafe/play/play-cache_2.10/2.2.0/play-cache_2.10-2.2.0.pom
       [info] Resolving net.sf.ehcache#ehcache-core;2.6.6 ...
       [info] Resolving net.sf.ehcache#ehcache-parent;2.3 ...
       [info] Resolving com.typesafe.play#play-test_2.10;2.2.0 ...
       [info] Resolving junit#junit;4.11 ...
       [info] Resolving org.hamcrest#hamcrest-core;1.3 ...
       [info] Resolving org.hamcrest#hamcrest-parent;1.3 ...
       [info] Resolving org.specs2#specs2_2.10;2.1.1 ...
       [info] Resolving org.scalaz#scalaz-core_2.10;7.0.2 ...
       [info] Resolving org.scalaz#scalaz-concurrent_2.10;7.0.2 ...
       [info] Resolving org.scalaz#scalaz-effect_2.10;7.0.2 ...
       [info] Resolving com.novocode#junit-interface;0.10 ...
       [info] Resolving org.scala-tools.testing#test-interface;0.5 ...
       [info] Resolving org.fluentlenium#fluentlenium-festassert;0.8.0 ...
       [info] Resolving org.fluentlenium#fluentlenium-parent;0.8.0 ...
       [info] Resolving org.sonatype.oss#oss-parent;7 ...
       [info] Resolving org.fluentlenium#fluentlenium-core;0.8.0 ...
       [info] Resolving org.fluentlenium#fluentlenium-parent;0.8.0 ...
       [info] Resolving org.seleniumhq.selenium#selenium-java;2.32.0 ...
       [info] Resolving org.seleniumhq.selenium#selenium-parent;2.32.0 ...
       [info] Resolving org.seleniumhq.selenium#selenium-android-driver;2.32.0 ...
       [info] Resolving org.seleniumhq.selenium#selenium-parent;2.32.0 ...
       [info] Resolving org.seleniumhq.selenium#selenium-remote-driver;2.32.0 ...
       [info] Resolving org.seleniumhq.selenium#selenium-parent;2.32.0 ...
       [info] Resolving cglib#cglib-nodep;2.1_3 ...
       [info] Resolving org.json#json;20080701 ...
       [info] Resolving org.seleniumhq.selenium#selenium-api;2.32.0 ...
       [info] Resolving org.seleniumhq.selenium#selenium-parent;2.32.0 ...
       [info] Resolving org.apache.httpcomponents#httpclient;4.2.1 ...
       [info] Resolving org.apache.httpcomponents#httpcomponents-client;4.2.1 ...
       [info] Resolving org.apache.httpcomponents#project;6 ...
       [info] Resolving org.apache.httpcomponents#httpcore;4.2.1 ...
       [info] Resolving org.apache.httpcomponents#httpcomponents-core;4.2.1 ...
       [info] Resolving org.apache.httpcomponents#project;6 ...
       [info] Resolving commons-codec#commons-codec;1.6 ...
       [info] Resolving org.apache.commons#commons-parent;22 ...
       [info] Resolving org.apache.commons#commons-exec;1.1 ...
       [info] Resolving org.apache.commons#commons-parent;17 ...
       [info] Resolving org.apache#apache;7 ...
       [info] Resolving net.java.dev.jna#jna;3.4.0 ...
       [info] Resolving net.java.dev.jna#platform;3.4.0 ...
       [info] Resolving org.seleniumhq.selenium#selenium-chrome-driver;2.32.0 ...
       [info] Resolving org.seleniumhq.selenium#selenium-parent;2.32.0 ...
       [info] Resolving org.seleniumhq.selenium#selenium-htmlunit-driver;2.32.0 ...
       [info] Resolving org.seleniumhq.selenium#selenium-parent;2.32.0 ...
       [info] Resolving net.sourceforge.htmlunit#htmlunit;2.12 ...
       [info] Resolving xalan#xalan;2.7.1 ...
       [info] Resolving org.apache#apache;4 ...
       [info] Resolving xalan#serializer;2.7.1 ...
       [info] Resolving org.apache#apache;4 ...
       [info] Resolving commons-collections#commons-collections;3.2.1 ...
       [info] Resolving org.apache.commons#commons-parent;9 ...
       [info] Resolving org.apache#apache;4 ...
       [info] Resolving org.apache.httpcomponents#httpmime;4.2.3 ...
       [info] Resolving org.apache.httpcomponents#httpcomponents-client;4.2.3 ...
       [info] Resolving org.apache.httpcomponents#project;6 ...
       [info] Resolving net.sourceforge.htmlunit#htmlunit-core-js;2.12 ...
       [info] Resolving net.sourceforge.nekohtml#nekohtml;1.9.18 ...
       [info] Resolving net.sourceforge.cssparser#cssparser;0.9.9 ...
       [info] Resolving org.sonatype.oss#oss-parent;7 ...
       [info] Resolving org.w3c.css#sac;1.3 ...
       [info] Resolving commons-io#commons-io;2.2 ...
       [info] Resolving org.apache.commons#commons-parent;24 ...
       [info] Resolving org.eclipse.jetty#jetty-websocket;8.1.9.v20130131 ...
       [info] Resolving org.eclipse.jetty#jetty-project;8.1.9.v20130131 ...
       [info] Resolving org.eclipse.jetty#jetty-parent;20 ...
       [info] Resolving org.eclipse.jetty#jetty-util;8.1.9.v20130131 ...
       [info] Resolving org.eclipse.jetty#jetty-project;8.1.9.v20130131 ...
       [info] Resolving org.eclipse.jetty#jetty-io;8.1.9.v20130131 ...
       [info] Resolving org.eclipse.jetty#jetty-project;8.1.9.v20130131 ...
       [info] Resolving org.eclipse.jetty#jetty-http;8.1.9.v20130131 ...
       [info] Resolving org.eclipse.jetty#jetty-project;8.1.9.v20130131 ...
       [info] Resolving org.seleniumhq.selenium#selenium-firefox-driver;2.32.0 ...
       [info] Resolving org.seleniumhq.selenium#selenium-parent;2.32.0 ...
       [info] Resolving org.seleniumhq.selenium#selenium-ie-driver;2.32.0 ...
       [info] Resolving org.seleniumhq.selenium#selenium-parent;2.32.0 ...
       [info] Resolving org.seleniumhq.selenium#selenium-iphone-driver;2.32.0 ...
       [info] Resolving org.seleniumhq.selenium#selenium-parent;2.32.0 ...
       [info] Resolving org.seleniumhq.selenium#selenium-safari-driver;2.32.0 ...
       [info] Resolving org.seleniumhq.selenium#selenium-parent;2.32.0 ...
       [info] Resolving org.webbitserver#webbit;0.4.14 ...
       [info] Resolving org.sonatype.oss#oss-parent;6 ...
       [info] Resolving org.seleniumhq.selenium#selenium-support;2.32.0 ...
       [info] Resolving org.seleniumhq.selenium#selenium-parent;2.32.0 ...
       [info] Resolving org.easytesting#fest-assert;1.4 ...
       [info] Resolving org.easytesting#fest;1.0.8 ...
       [info] Resolving org.easytesting#fest-util;1.1.6 ...
       [info] Resolving org.easytesting#fest;1.0.8 ...
       [info] Resolving com.typesafe.play#play-docs_2.10;2.2.0 ...
       [info] Resolving org.scala-lang#scala-library;2.10.0 ...
       [info] Resolving com.typesafe.play#play-doc_2.10;1.0.3 ...
       [info] Resolving org.pegdown#pegdown;1.4.0 ...
       [info] Resolving org.parboiled#parboiled-java;1.1.5 ...
       [info] Resolving org.parboiled#parboiled-core;1.1.5 ...
       [info] Resolving org.ow2.asm#asm;4.1 ...
       [info] Resolving org.ow2.asm#asm-parent;4.1 ...
       [info] Resolving org.ow2#ow2;1.3 ...
       [info] Resolving org.ow2.asm#asm-tree;4.1 ...
       [info] Resolving org.ow2.asm#asm-parent;4.1 ...
       [info] Resolving org.ow2.asm#asm-analysis;4.1 ...
       [info] Resolving org.ow2.asm#asm-parent;4.1 ...
       [info] Resolving org.ow2.asm#asm-util;4.1 ...
       [info] Resolving org.ow2.asm#asm-parent;4.1 ...
       [info] Resolving commons-io#commons-io;2.4 ...
       [info] Resolving org.apache.commons#commons-parent;25 ...
       [info] Resolving org.apache#apache;9 ...
       [info] Resolving org.scala-lang#scala-compiler;2.10.2 ...
       [info] Resolving org.scala-lang#jline;2.10.2 ...
       [info] Resolving org.fusesource.jansi#jansi;1.4 ...
       [info] downloading http://typesafe.artifactoryonline.com/typesafe/releases/com/typesafe/play/play-java-jdbc_2.10/2.2.0/play-java-jdbc_2.10-2.2.0.jar ...
       [info] 	[SUCCESSFUL ] com.typesafe.play#play-java-jdbc_2.10;2.2.0!play-java-jdbc_2.10.jar (78ms)
       [info] downloading http://typesafe.artifactoryonline.com/typesafe/releases/com/typesafe/play/play-java-ebean_2.10/2.2.0/play-java-ebean_2.10-2.2.0.jar ...
       [info] 	[SUCCESSFUL ] com.typesafe.play#play-java-ebean_2.10;2.2.0!play-java-ebean_2.10.jar (79ms)
       [info] downloading http://typesafe.artifactoryonline.com/typesafe/releases/com/typesafe/play/play-cache_2.10/2.2.0/play-cache_2.10-2.2.0.jar ...
       [info] 	[SUCCESSFUL ] com.typesafe.play#play-cache_2.10;2.2.0!play-cache_2.10.jar (77ms)
       [info] downloading http://typesafe.artifactoryonline.com/typesafe/releases/com/typesafe/play/play_2.10/2.2.0/play_2.10-2.2.0.jar ...
       [info] 	[SUCCESSFUL ] com.typesafe.play#play_2.10;2.2.0!play_2.10.jar (470ms)
       [info] downloading http://typesafe.artifactoryonline.com/typesafe/releases/com/typesafe/play/play-java_2.10/2.2.0/play-java_2.10-2.2.0.jar ...
       [info] 	[SUCCESSFUL ] com.typesafe.play#play-java_2.10;2.2.0!play-java_2.10.jar (111ms)
       [info] downloading http://typesafe.artifactoryonline.com/typesafe/releases/com/typesafe/play/play-jdbc_2.10/2.2.0/play-jdbc_2.10-2.2.0.jar ...
       [info] 	[SUCCESSFUL ] com.typesafe.play#play-jdbc_2.10;2.2.0!play-jdbc_2.10.jar (133ms)
       [info] downloading http://s3pository.heroku.com/maven-central/com/jolbox/bonecp/0.8.0-rc1/bonecp-0.8.0-rc1.jar ...
       [info] 	[SUCCESSFUL ] com.jolbox#bonecp;0.8.0-rc1!bonecp.jar(bundle) (311ms)
       [info] downloading http://s3pository.heroku.com/maven-central/tyrex/tyrex/1.0.1/tyrex-1.0.1.jar ...
       [info] 	[SUCCESSFUL ] tyrex#tyrex;1.0.1!tyrex.jar (276ms)
       [info] downloading http://typesafe.artifactoryonline.com/typesafe/releases/com/typesafe/play/templates_2.10/2.2.0/templates_2.10-2.2.0.jar ...
       [info] 	[SUCCESSFUL ] com.typesafe.play#templates_2.10;2.2.0!templates_2.10.jar (107ms)
       [info] downloading http://typesafe.artifactoryonline.com/typesafe/releases/com/typesafe/play/play-iteratees_2.10/2.2.0/play-iteratees_2.10-2.2.0.jar ...
       [info] 	[SUCCESSFUL ] com.typesafe.play#play-iteratees_2.10;2.2.0!play-iteratees_2.10.jar (138ms)
       [info] downloading http://typesafe.artifactoryonline.com/typesafe/releases/com/typesafe/play/play-json_2.10/2.2.0/play-json_2.10-2.2.0.jar ...
       [info] 	[SUCCESSFUL ] com.typesafe.play#play-json_2.10;2.2.0!play-json_2.10.jar (113ms)
       [info] downloading http://s3pository.heroku.com/maven-central/io/netty/netty/3.7.0.Final/netty-3.7.0.Final.jar ...
       [info] 	[SUCCESSFUL ] io.netty#netty;3.7.0.Final!netty.jar(bundle) (448ms)
       [info] downloading http://typesafe.artifactoryonline.com/typesafe/releases/com/typesafe/netty/netty-http-pipelining/1.1.2/netty-http-pipelining-1.1.2.jar ...
       [info] 	[SUCCESSFUL ] com.typesafe.netty#netty-http-pipelining;1.1.2!netty-http-pipelining.jar (74ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/slf4j/slf4j-api/1.7.5/slf4j-api-1.7.5.jar ...
       [info] 	[SUCCESSFUL ] org.slf4j#slf4j-api;1.7.5!slf4j-api.jar (179ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/slf4j/jul-to-slf4j/1.7.5/jul-to-slf4j-1.7.5.jar ...
       [info] 	[SUCCESSFUL ] org.slf4j#jul-to-slf4j;1.7.5!jul-to-slf4j.jar (190ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/slf4j/jcl-over-slf4j/1.7.5/jcl-over-slf4j-1.7.5.jar ...
       [info] 	[SUCCESSFUL ] org.slf4j#jcl-over-slf4j;1.7.5!jcl-over-slf4j.jar (218ms)
       [info] downloading http://s3pository.heroku.com/maven-central/ch/qos/logback/logback-core/1.0.13/logback-core-1.0.13.jar ...
       [info] 	[SUCCESSFUL ] ch.qos.logback#logback-core;1.0.13!logback-core.jar (487ms)
       [info] downloading http://s3pository.heroku.com/maven-central/ch/qos/logback/logback-classic/1.0.13/logback-classic-1.0.13.jar ...
       [info] 	[SUCCESSFUL ] ch.qos.logback#logback-classic;1.0.13!logback-classic.jar (332ms)
       [info] downloading http://s3pository.heroku.com/maven-central/com/typesafe/akka/akka-actor_2.10/2.2.0/akka-actor_2.10-2.2.0.jar ...
       [info] 	[SUCCESSFUL ] com.typesafe.akka#akka-actor_2.10;2.2.0!akka-actor_2.10.jar (402ms)
       [info] downloading http://s3pository.heroku.com/maven-central/com/typesafe/akka/akka-slf4j_2.10/2.2.0/akka-slf4j_2.10-2.2.0.jar ...
       [info] 	[SUCCESSFUL ] com.typesafe.akka#akka-slf4j_2.10;2.2.0!akka-slf4j_2.10.jar(bundle) (226ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/scala-stm/scala-stm_2.10/0.7/scala-stm_2.10-0.7.jar ...
       [info] 	[SUCCESSFUL ] org.scala-stm#scala-stm_2.10;0.7!scala-stm_2.10.jar (493ms)
       [info] downloading http://s3pository.heroku.com/maven-central/joda-time/joda-time/2.2/joda-time-2.2.jar ...
       [info] 	[SUCCESSFUL ] joda-time#joda-time;2.2!joda-time.jar (350ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/joda/joda-convert/1.3.1/joda-convert-1.3.1.jar ...
       [info] 	[SUCCESSFUL ] org.joda#joda-convert;1.3.1!joda-convert.jar (161ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/apache/commons/commons-lang3/3.1/commons-lang3-3.1.jar ...
       [info] 	[SUCCESSFUL ] org.apache.commons#commons-lang3;3.1!commons-lang3.jar (324ms)
       [info] downloading http://s3pository.heroku.com/maven-central/com/ning/async-http-client/1.7.18/async-http-client-1.7.18.jar ...
       [info] 	[SUCCESSFUL ] com.ning#async-http-client;1.7.18!async-http-client.jar (262ms)
       [info] downloading http://s3pository.heroku.com/maven-central/oauth/signpost/signpost-core/1.2.1.2/signpost-core-1.2.1.2.jar ...
       [info] 	[SUCCESSFUL ] oauth.signpost#signpost-core;1.2.1.2!signpost-core.jar (462ms)
       [info] downloading http://s3pository.heroku.com/maven-central/oauth/signpost/signpost-commonshttp4/1.2.1.2/signpost-commonshttp4-1.2.1.2.jar ...
       [info] 	[SUCCESSFUL ] oauth.signpost#signpost-commonshttp4;1.2.1.2!signpost-commonshttp4.jar (213ms)
       [info] downloading http://s3pository.heroku.com/maven-central/com/fasterxml/jackson/core/jackson-core/2.2.2/jackson-core-2.2.2.jar ...
       [info] 	[SUCCESSFUL ] com.fasterxml.jackson.core#jackson-core;2.2.2!jackson-core.jar (257ms)
       [info] downloading http://s3pository.heroku.com/maven-central/com/fasterxml/jackson/core/jackson-annotations/2.2.2/jackson-annotations-2.2.2.jar ...
       [info] 	[SUCCESSFUL ] com.fasterxml.jackson.core#jackson-annotations;2.2.2!jackson-annotations.jar (231ms)
       [info] downloading http://s3pository.heroku.com/maven-central/com/fasterxml/jackson/core/jackson-databind/2.2.2/jackson-databind-2.2.2.jar ...
       [info] 	[SUCCESSFUL ] com.fasterxml.jackson.core#jackson-databind;2.2.2!jackson-databind.jar (448ms)
       [info] downloading http://s3pository.heroku.com/maven-central/xerces/xercesImpl/2.11.0/xercesImpl-2.11.0.jar ...
       [info] 	[SUCCESSFUL ] xerces#xercesImpl;2.11.0!xercesImpl.jar (407ms)
       [info] downloading http://s3pository.heroku.com/maven-central/javax/transaction/jta/1.1/jta-1.1.jar ...
       [info] 	[SUCCESSFUL ] javax.transaction#jta;1.1!jta.jar (209ms)
       [info] downloading http://typesafe.artifactoryonline.com/typesafe/releases/com/typesafe/play/play-functional_2.10/2.2.0/play-functional_2.10-2.2.0.jar ...
       [info] 	[SUCCESSFUL ] com.typesafe.play#play-functional_2.10;2.2.0!play-functional_2.10.jar (103ms)
       [info] downloading http://typesafe.artifactoryonline.com/typesafe/releases/com/typesafe/play/play-datacommons_2.10/2.2.0/play-datacommons_2.10-2.2.0.jar ...
       [info] 	[SUCCESSFUL ] com.typesafe.play#play-datacommons_2.10;2.2.0!play-datacommons_2.10.jar (84ms)
       [info] downloading http://s3pository.heroku.com/maven-central/commons-codec/commons-codec/1.3/commons-codec-1.3.jar ...
       [info] 	[SUCCESSFUL ] commons-codec#commons-codec;1.3!commons-codec.jar (165ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/apache/httpcomponents/httpcore/4.0.1/httpcore-4.0.1.jar ...
       [info] 	[SUCCESSFUL ] org.apache.httpcomponents#httpcore;4.0.1!httpcore.jar (289ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/apache/httpcomponents/httpclient/4.0.1/httpclient-4.0.1.jar ...
       [info] 	[SUCCESSFUL ] org.apache.httpcomponents#httpclient;4.0.1!httpclient.jar (442ms)
       [info] downloading http://s3pository.heroku.com/maven-central/commons-logging/commons-logging/1.1.1/commons-logging-1.1.1.jar ...
       [info] 	[SUCCESSFUL ] commons-logging#commons-logging;1.1.1!commons-logging.jar (239ms)
       [info] downloading http://s3pository.heroku.com/maven-central/xml-apis/xml-apis/1.4.01/xml-apis-1.4.01.jar ...
       [info] 	[SUCCESSFUL ] xml-apis#xml-apis;1.4.01!xml-apis.jar (394ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/yaml/snakeyaml/1.12/snakeyaml-1.12.jar ...
       [info] 	[SUCCESSFUL ] org.yaml#snakeyaml;1.12!snakeyaml.jar(bundle) (374ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/hibernate/hibernate-validator/5.0.1.Final/hibernate-validator-5.0.1.Final.jar ...
       [info] 	[SUCCESSFUL ] org.hibernate#hibernate-validator;5.0.1.Final!hibernate-validator.jar (282ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/springframework/spring-context/3.2.3.RELEASE/spring-context-3.2.3.RELEASE.jar ...
       [info] 	[SUCCESSFUL ] org.springframework#spring-context;3.2.3.RELEASE!spring-context.jar (250ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/springframework/spring-core/3.2.3.RELEASE/spring-core-3.2.3.RELEASE.jar ...
       [info] 	[SUCCESSFUL ] org.springframework#spring-core;3.2.3.RELEASE!spring-core.jar (363ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/springframework/spring-beans/3.2.3.RELEASE/spring-beans-3.2.3.RELEASE.jar ...
       [info] 	[SUCCESSFUL ] org.springframework#spring-beans;3.2.3.RELEASE!spring-beans.jar (238ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/reflections/reflections/0.9.8/reflections-0.9.8.jar ...
       [info] 	[SUCCESSFUL ] org.reflections#reflections;0.9.8!reflections.jar (687ms)
       [info] downloading http://s3pository.heroku.com/maven-central/com/google/code/findbugs/jsr305/2.0.1/jsr305-2.0.1.jar ...
       [info] 	[SUCCESSFUL ] com.google.code.findbugs#jsr305;2.0.1!jsr305.jar (523ms)
       [info] downloading http://s3pository.heroku.com/maven-central/javax/servlet/javax.servlet-api/3.0.1/javax.servlet-api-3.0.1.jar ...
       [info] 	[SUCCESSFUL ] javax.servlet#javax.servlet-api;3.0.1!javax.servlet-api.jar (306ms)
       [info] downloading http://s3pository.heroku.com/maven-central/javax/validation/validation-api/1.1.0.Final/validation-api-1.1.0.Final.jar ...
       [info] 	[SUCCESSFUL ] javax.validation#validation-api;1.1.0.Final!validation-api.jar (222ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/jboss/logging/jboss-logging/3.1.1.GA/jboss-logging-3.1.1.GA.jar ...
       [info] 	[SUCCESSFUL ] org.jboss.logging#jboss-logging;3.1.1.GA!jboss-logging.jar (206ms)
       [info] downloading http://s3pository.heroku.com/maven-central/com/fasterxml/classmate/0.8.0/classmate-0.8.0.jar ...
       [info] 	[SUCCESSFUL ] com.fasterxml#classmate;0.8.0!classmate.jar(bundle) (387ms)
       [info] downloading http://s3pository.heroku.com/maven-central/dom4j/dom4j/1.6.1/dom4j-1.6.1.jar ...
       [info] 	[SUCCESSFUL ] dom4j#dom4j;1.6.1!dom4j.jar (746ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/avaje/ebeanorm/avaje-ebeanorm/3.2.2/avaje-ebeanorm-3.2.2.jar ...
       [info] 	[SUCCESSFUL ] org.avaje.ebeanorm#avaje-ebeanorm;3.2.2!avaje-ebeanorm.jar (549ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/hibernate/javax/persistence/hibernate-jpa-2.0-api/1.0.1.Final/hibernate-jpa-2.0-api-1.0.1.Final.jar ...
       [info] 	[SUCCESSFUL ] org.hibernate.javax.persistence#hibernate-jpa-2.0-api;1.0.1.Final!hibernate-jpa-2.0-api.jar (241ms)
       [info] downloading http://s3pository.heroku.com/maven-central/net/sf/ehcache/ehcache-core/2.6.6/ehcache-core-2.6.6.jar ...
       [info] 	[SUCCESSFUL ] net.sf.ehcache#ehcache-core;2.6.6!ehcache-core.jar (810ms)
       [info] downloading http://typesafe.artifactoryonline.com/typesafe/releases/com/typesafe/play/play-test_2.10/2.2.0/play-test_2.10-2.2.0.jar ...
       [info] 	[SUCCESSFUL ] com.typesafe.play#play-test_2.10;2.2.0!play-test_2.10.jar (160ms)
       [info] downloading http://s3pository.heroku.com/maven-central/junit/junit/4.11/junit-4.11.jar ...
       [info] 	[SUCCESSFUL ] junit#junit;4.11!junit.jar (333ms)
       [info] downloading http://s3pository.heroku.com/maven-central/com/novocode/junit-interface/0.10/junit-interface-0.10.jar ...
       [info] 	[SUCCESSFUL ] com.novocode#junit-interface;0.10!junit-interface.jar (258ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/fluentlenium/fluentlenium-festassert/0.8.0/fluentlenium-festassert-0.8.0.jar ...
       [info] 	[SUCCESSFUL ] org.fluentlenium#fluentlenium-festassert;0.8.0!fluentlenium-festassert.jar (1033ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/hamcrest/hamcrest-core/1.3/hamcrest-core-1.3.jar ...
       [info] 	[SUCCESSFUL ] org.hamcrest#hamcrest-core;1.3!hamcrest-core.jar (173ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/scala-tools/testing/test-interface/0.5/test-interface-0.5.jar ...
       [info] 	[SUCCESSFUL ] org.scala-tools.testing#test-interface;0.5!test-interface.jar (275ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/fluentlenium/fluentlenium-core/0.8.0/fluentlenium-core-0.8.0.jar ...
       [info] 	[SUCCESSFUL ] org.fluentlenium#fluentlenium-core;0.8.0!fluentlenium-core.jar (562ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/easytesting/fest-assert/1.4/fest-assert-1.4.jar ...
       [info] 	[SUCCESSFUL ] org.easytesting#fest-assert;1.4!fest-assert.jar (320ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/seleniumhq/selenium/selenium-java/2.32.0/selenium-java-2.32.0.jar ...
       [info] 	[SUCCESSFUL ] org.seleniumhq.selenium#selenium-java;2.32.0!selenium-java.jar (402ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/seleniumhq/selenium/selenium-android-driver/2.32.0/selenium-android-driver-2.32.0.jar ...
       [info] 	[SUCCESSFUL ] org.seleniumhq.selenium#selenium-android-driver;2.32.0!selenium-android-driver.jar (313ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/seleniumhq/selenium/selenium-chrome-driver/2.32.0/selenium-chrome-driver-2.32.0.jar ...
       [info] 	[SUCCESSFUL ] org.seleniumhq.selenium#selenium-chrome-driver;2.32.0!selenium-chrome-driver.jar (319ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/seleniumhq/selenium/selenium-htmlunit-driver/2.32.0/selenium-htmlunit-driver-2.32.0.jar ...
       [info] 	[SUCCESSFUL ] org.seleniumhq.selenium#selenium-htmlunit-driver;2.32.0!selenium-htmlunit-driver.jar (352ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/seleniumhq/selenium/selenium-firefox-driver/2.32.0/selenium-firefox-driver-2.32.0.jar ...
       [info] 	[SUCCESSFUL ] org.seleniumhq.selenium#selenium-firefox-driver;2.32.0!selenium-firefox-driver.jar (535ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/seleniumhq/selenium/selenium-ie-driver/2.32.0/selenium-ie-driver-2.32.0.jar ...
       [info] 	[SUCCESSFUL ] org.seleniumhq.selenium#selenium-ie-driver;2.32.0!selenium-ie-driver.jar (251ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/seleniumhq/selenium/selenium-iphone-driver/2.32.0/selenium-iphone-driver-2.32.0.jar ...
       [info] 	[SUCCESSFUL ] org.seleniumhq.selenium#selenium-iphone-driver;2.32.0!selenium-iphone-driver.jar (258ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/seleniumhq/selenium/selenium-safari-driver/2.32.0/selenium-safari-driver-2.32.0.jar ...
       [info] 	[SUCCESSFUL ] org.seleniumhq.selenium#selenium-safari-driver;2.32.0!selenium-safari-driver.jar (272ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/seleniumhq/selenium/selenium-support/2.32.0/selenium-support-2.32.0.jar ...
       [info] 	[SUCCESSFUL ] org.seleniumhq.selenium#selenium-support;2.32.0!selenium-support.jar (558ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/webbitserver/webbit/0.4.14/webbit-0.4.14.jar ...
       [info] 	[SUCCESSFUL ] org.webbitserver#webbit;0.4.14!webbit.jar (327ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/seleniumhq/selenium/selenium-remote-driver/2.32.0/selenium-remote-driver-2.32.0.jar ...
       [info] 	[SUCCESSFUL ] org.seleniumhq.selenium#selenium-remote-driver;2.32.0!selenium-remote-driver.jar (455ms)
       [info] downloading http://s3pository.heroku.com/maven-central/cglib/cglib-nodep/2.1_3/cglib-nodep-2.1_3.jar ...
       [info] 	[SUCCESSFUL ] cglib#cglib-nodep;2.1_3!cglib-nodep.jar (462ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/json/json/20080701/json-20080701.jar ...
       [info] 	[SUCCESSFUL ] org.json#json;20080701!json.jar (322ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/seleniumhq/selenium/selenium-api/2.32.0/selenium-api-2.32.0.jar ...
       [info] 	[SUCCESSFUL ] org.seleniumhq.selenium#selenium-api;2.32.0!selenium-api.jar (285ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/apache/httpcomponents/httpclient/4.2.1/httpclient-4.2.1.jar ...
       [info] 	[SUCCESSFUL ] org.apache.httpcomponents#httpclient;4.2.1!httpclient.jar (343ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/apache/commons/commons-exec/1.1/commons-exec-1.1.jar ...
       [info] 	[SUCCESSFUL ] org.apache.commons#commons-exec;1.1!commons-exec.jar (220ms)
       [info] downloading http://s3pository.heroku.com/maven-central/net/java/dev/jna/jna/3.4.0/jna-3.4.0.jar ...
       [info] 	[SUCCESSFUL ] net.java.dev.jna#jna;3.4.0!jna.jar (543ms)
       [info] downloading http://s3pository.heroku.com/maven-central/net/java/dev/jna/platform/3.4.0/platform-3.4.0.jar ...
       [info] 	[SUCCESSFUL ] net.java.dev.jna#platform;3.4.0!platform.jar (402ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/apache/httpcomponents/httpcore/4.2.1/httpcore-4.2.1.jar ...
       [info] 	[SUCCESSFUL ] org.apache.httpcomponents#httpcore;4.2.1!httpcore.jar (258ms)
       [info] downloading http://s3pository.heroku.com/maven-central/commons-codec/commons-codec/1.6/commons-codec-1.6.jar ...
       [info] 	[SUCCESSFUL ] commons-codec#commons-codec;1.6!commons-codec.jar (450ms)
       [info] downloading http://s3pository.heroku.com/maven-central/net/sourceforge/htmlunit/htmlunit/2.12/htmlunit-2.12.jar ...
       [info] 	[SUCCESSFUL ] net.sourceforge.htmlunit#htmlunit;2.12!htmlunit.jar (835ms)
       [info] downloading http://s3pository.heroku.com/maven-central/xalan/xalan/2.7.1/xalan-2.7.1.jar ...
       [info] 	[SUCCESSFUL ] xalan#xalan;2.7.1!xalan.jar (575ms)
       [info] downloading http://s3pository.heroku.com/maven-central/commons-collections/commons-collections/3.2.1/commons-collections-3.2.1.jar ...
       [info] 	[SUCCESSFUL ] commons-collections#commons-collections;3.2.1!commons-collections.jar (353ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/apache/httpcomponents/httpmime/4.2.3/httpmime-4.2.3.jar ...
       [info] 	[SUCCESSFUL ] org.apache.httpcomponents#httpmime;4.2.3!httpmime.jar (429ms)
       [info] downloading http://s3pository.heroku.com/maven-central/net/sourceforge/htmlunit/htmlunit-core-js/2.12/htmlunit-core-js-2.12.jar ...
       [info] 	[SUCCESSFUL ] net.sourceforge.htmlunit#htmlunit-core-js;2.12!htmlunit-core-js.jar (500ms)
       [info] downloading http://s3pository.heroku.com/maven-central/net/sourceforge/nekohtml/nekohtml/1.9.18/nekohtml-1.9.18.jar ...
       [info] 	[SUCCESSFUL ] net.sourceforge.nekohtml#nekohtml;1.9.18!nekohtml.jar (372ms)
       [info] downloading http://s3pository.heroku.com/maven-central/net/sourceforge/cssparser/cssparser/0.9.9/cssparser-0.9.9.jar ...
       [info] 	[SUCCESSFUL ] net.sourceforge.cssparser#cssparser;0.9.9!cssparser.jar (330ms)
       [info] downloading http://s3pository.heroku.com/maven-central/commons-io/commons-io/2.2/commons-io-2.2.jar ...
       [info] 	[SUCCESSFUL ] commons-io#commons-io;2.2!commons-io.jar (355ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/eclipse/jetty/jetty-websocket/8.1.9.v20130131/jetty-websocket-8.1.9.v20130131.jar ...
       [info] 	[SUCCESSFUL ] org.eclipse.jetty#jetty-websocket;8.1.9.v20130131!jetty-websocket.jar (139ms)
       [info] downloading http://s3pository.heroku.com/maven-central/xalan/serializer/2.7.1/serializer-2.7.1.jar ...
       [info] 	[SUCCESSFUL ] xalan#serializer;2.7.1!serializer.jar (290ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/w3c/css/sac/1.3/sac-1.3.jar ...
       [info] 	[SUCCESSFUL ] org.w3c.css#sac;1.3!sac.jar (214ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/eclipse/jetty/jetty-util/8.1.9.v20130131/jetty-util-8.1.9.v20130131.jar ...
       [info] 	[SUCCESSFUL ] org.eclipse.jetty#jetty-util;8.1.9.v20130131!jetty-util.jar (502ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/eclipse/jetty/jetty-io/8.1.9.v20130131/jetty-io-8.1.9.v20130131.jar ...
       [info] 	[SUCCESSFUL ] org.eclipse.jetty#jetty-io;8.1.9.v20130131!jetty-io.jar (408ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/eclipse/jetty/jetty-http/8.1.9.v20130131/jetty-http-8.1.9.v20130131.jar ...
       [info] 	[SUCCESSFUL ] org.eclipse.jetty#jetty-http;8.1.9.v20130131!jetty-http.jar (542ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/easytesting/fest-util/1.1.6/fest-util-1.1.6.jar ...
       [info] 	[SUCCESSFUL ] org.easytesting#fest-util;1.1.6!fest-util.jar (472ms)
       [info] downloading http://typesafe.artifactoryonline.com/typesafe/releases/com/typesafe/play/play-docs_2.10/2.2.0/play-docs_2.10-2.2.0.jar ...
       [info] 	[SUCCESSFUL ] com.typesafe.play#play-docs_2.10;2.2.0!play-docs_2.10.jar (1215ms)
       [info] downloading http://typesafe.artifactoryonline.com/typesafe/releases/com/typesafe/play/play-doc_2.10/1.0.3/play-doc_2.10-1.0.3.jar ...
       [info] 	[SUCCESSFUL ] com.typesafe.play#play-doc_2.10;1.0.3!play-doc_2.10.jar (134ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/pegdown/pegdown/1.4.0/pegdown-1.4.0.jar ...
       [info] 	[SUCCESSFUL ] org.pegdown#pegdown;1.4.0!pegdown.jar (242ms)
       [info] downloading http://s3pository.heroku.com/maven-central/commons-io/commons-io/2.4/commons-io-2.4.jar ...
       [info] 	[SUCCESSFUL ] commons-io#commons-io;2.4!commons-io.jar (534ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/parboiled/parboiled-java/1.1.5/parboiled-java-1.1.5.jar ...
       [info] 	[SUCCESSFUL ] org.parboiled#parboiled-java;1.1.5!parboiled-java.jar(bundle) (228ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/parboiled/parboiled-core/1.1.5/parboiled-core-1.1.5.jar ...
       [info] 	[SUCCESSFUL ] org.parboiled#parboiled-core;1.1.5!parboiled-core.jar(bundle) (170ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/ow2/asm/asm/4.1/asm-4.1.jar ...
       [info] 	[SUCCESSFUL ] org.ow2.asm#asm;4.1!asm.jar (171ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/ow2/asm/asm-tree/4.1/asm-tree-4.1.jar ...
       [info] 	[SUCCESSFUL ] org.ow2.asm#asm-tree;4.1!asm-tree.jar (354ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/ow2/asm/asm-analysis/4.1/asm-analysis-4.1.jar ...
       [info] 	[SUCCESSFUL ] org.ow2.asm#asm-analysis;4.1!asm-analysis.jar (249ms)
       [info] downloading http://s3pository.heroku.com/maven-central/org/ow2/asm/asm-util/4.1/asm-util-4.1.jar ...
       [info] 	[SUCCESSFUL ] org.ow2.asm#asm-util;4.1!asm-util.jar (282ms)
       [info] Done updating.
       [info] Compiling 5 Scala sources and 3 Java sources to /tmp/build_3ae9a649-b02b-41f5-ac89-f0034c39a122/target/scala-2.10/classes...
       [success] Total time: 132 s, completed Oct 3, 2013 9:17:51 PM
       [info] Packaging /tmp/build_3ae9a649-b02b-41f5-ac89-f0034c39a122/target/scala-2.10/mywebsocketapp_2.10-1.0-SNAPSHOT-sources.jar ...
       [info] Done packaging.
       [info] Wrote /tmp/build_3ae9a649-b02b-41f5-ac89-f0034c39a122/target/scala-2.10/mywebsocketapp_2.10-1.0-SNAPSHOT.pom
       [info] Main Scala API documentation to /tmp/build_3ae9a649-b02b-41f5-ac89-f0034c39a122/target/scala-2.10/api...
       [info] Packaging /tmp/build_3ae9a649-b02b-41f5-ac89-f0034c39a122/target/scala-2.10/mywebsocketapp_2.10-1.0-SNAPSHOT.jar ...
       [info] Done packaging.
       model contains 21 documentable templates
       [info] Main Scala API documentation successful.
       [info] Packaging /tmp/build_3ae9a649-b02b-41f5-ac89-f0034c39a122/target/scala-2.10/mywebsocketapp_2.10-1.0-SNAPSHOT-javadoc.jar ...
       [info] Done packaging.
       [success] Total time: 5 s, completed Oct 3, 2013 9:17:56 PM
-----> Dropping ivy cache from the slug
-----> Discovering process types
       Procfile declares types           -> (none)
       Default types for Play 2.x - Java -> web

-----> Compiled slug size: 117.4MB
-----> Launching... done, v6
       http://shrouded-basin-4761.herokuapp.com deployed to Heroku

To git@heroku.com:shrouded-basin-4761.git
 * [new branch]      master -> master


```

Congratulations! Your web app should now be up and running on Heroku.


